from django.contrib.auth.models import User
from django.db import models
from django.db.models.signals import post_save
from django.dispatch import receiver

from core import utils

class UserProfile(models.Model):
    user = models.OneToOneField(
        User,
        on_delete=models.CASCADE,
        related_name='profile',
    )
    notes = models.TextField(blank=True, null=True)

    def __str__(self):
        return self.user.username

    @property
    def todos(self):
        return utils.merge(
            self.user.boulder_todos.order_by('name'),
            self.user.route_todos.order_by('name'),
            'name',
        )

@receiver(post_save, sender=User)
def create_profile(sender, instance, **kwargs):
    profile, created = UserProfile.objects.get_or_create(user=instance)
